@@ -14,6 +14,7 @@
    Copyright 2021, HSPyLib team
 """
 import json
+import logging as log
 import os
 from abc import ABC
 from fnmatch import fnmatch
@@ -32,7 +33,7 @@ class FileProcessor(ABC):
     """Utility class to upload and download B64 encoded files"""
 
     @staticmethod
-    def upload_files(url: str, file_paths: List[str], glob_exp: str = '*.*') -> int:
+    def upload_files(url: str, file_paths: List[str], glob_exp: str) -> int:
         """Upload files to URL"""
         data = []
         for f_path in file_paths:
@@ -44,17 +45,12 @@ class FileProcessor(ABC):
             else:
                 sysout(f'Uploading files from "{f_path}" to Firebase ...')
                 all_files = next(os.walk(f_path))[2]
-                print('Cur Dir: ' + os.getcwd())
-                print('   Glob: ' + glob_exp)
-                print(' Target: ' + f_path)
-                print('  Files: [' + '  '.join(all_files) + ']')
+                log.debug('\nGlob: {} \nFiles: {}'.format(glob_exp, all_files))
                 for file in all_files:
                     filename = os.path.join(f_path, file)
-                    if os.path.isfile(filename) and fnmatch(filename, glob_exp):
+                    if os.path.isfile(filename) and fnmatch(file, glob_exp or '*.*'):
                         f_entry = FileProcessor._read_and_encode(filename)
                         data.append(f_entry)
-                    else:
-                        sysout(f'not a file or not match: {filename}')
         if data and len(data) > 0:
             payload = FileProcessor._to_json(data)
             response = put(url, payload)
